Struct amazon_sp_fulfillment_inbound::models::get_preorder_info_result::GetPreorderInfoResult
source · [−]pub struct GetPreorderInfoResult {
pub shipment_contains_preorderable_items: Option<bool>,
pub shipment_confirmed_for_preorder: Option<bool>,
pub need_by_date: Option<String>,
pub confirmed_fulfillable_date: Option<String>,
}Fields
shipment_contains_preorderable_items: Option<bool>Indicates whether the shipment contains items that have been enabled for pre-order. For more information about enabling items for pre-order, see the Seller Central Help.
shipment_confirmed_for_preorder: Option<bool>Indicates whether this shipment has been confirmed for pre-order.
need_by_date: Option<String>confirmed_fulfillable_date: Option<String>Implementations
sourceimpl GetPreorderInfoResult
impl GetPreorderInfoResult
pub fn new() -> GetPreorderInfoResult